#
# spec file for package tiff
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           tiff
BuildRequires:  gcc-c++ libjpeg-devel zlib-devel
License:        PERMISSIVE-OSI-COMPLIANT ; MIT License (or similar)
Group:          Productivity/Graphics/Convertors
AutoReqProv:    on
# bug437293
%ifarch ppc64
Obsoletes:      tiff-64bit
%endif
#
Url:            http://www.remotesensing.org/libtiff/
Version:        3.9.4
Release:        28.1
Summary:        Tools for Converting from and to the Tiff  Format
Source:         tiff-%{version}.tar.bz2
Source2:        README.SUSE
Source3:        baselibs.conf
Patch2:         tiff-%{version}-seek.patch
Patch3:         tiff-%{version}-tiff2pdf-colors.patch
Patch6:         tiff-%{version}-oob-read.patch
Patch7:         tiff-%{version}-getimage-64bit.patch
Patch8:         tiff-%{version}-scanlinesize.patch
Patch9:         tiff-%{version}-dont-fancy-upsampling.patch
Patch10:        tiff-%{version}-CVE-2011-0192.patch
Patch11:        tiff-%{version}-CVE-2011-1167.patch
Patch12:        tiff-3.9.4-CVE-2010-4665.patch
Patch13:        tiff-3.9.4-CVE-2009-5022.patch
Patch14:        tiff-3.9.4-CVE-2012-1173.patch
Patch15:        tiff-3.9.4-CVE-2012-2113.patch
Patch16:        tiff-3.9.4-CVE-2012-2088.patch
# FYI: this issue is solved another way
# http://bugzilla.maptools.org/show_bug.cgi?id=1985#c1
# Patch9:         tiff-%{version}-lzw-CVE-2009-2285.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package contains the library and support programs for the TIFF
image format.



Authors:
--------
    Sam Leffler <sam@engr.sgi.com>

%package -n libtiff3
License:        PERMISSIVE-OSI-COMPLIANT ; MIT License (or similar)
Summary:        The Tiff Library (with JPEG and compression support)
Group:          System/Libraries
Provides:       libtiff = %{version}
Obsoletes:      libtiff <= %{version}
AutoReqProv:    on
# bug437293
%ifarch ppc64
Obsoletes:      libtiff-64bit
%endif
#

%description -n libtiff3
This package includes the tiff libraries. To link a program with
libtiff, you will have to add -ljpeg and -lz to include the necessary
libjpeg and libz in the linking process.



Authors:
--------
    Sam Leffler <sam@engr.sgi.com>

%package -n libtiff-devel
License:        PERMISSIVE-OSI-COMPLIANT
Summary:        Development Tools for Programs which will use the libtiff Library
Group:          Development/Libraries/C and C++
Requires:       libtiff3 = %{version} libjpeg-devel zlib-devel libstdc++-devel glibc-devel
# bug437293
%ifarch ppc64
Obsoletes:      tiff-devel-64bit
%endif
#

%description -n libtiff-devel
This package contains the header files and static libraries for
developing programs which will manipulate TIFF format image files using
the libtiff library.



%prep
%setup -q 
%patch2
%patch3 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10
%patch11
%patch12
%patch13
%patch14
%patch15
%patch16
find -type d -name "CVS" | xargs rm -rfv
find -type d | xargs chmod 755

%build
rm m4/ltversion.m4 m4/ltsugar.m4 m4/ltoptions.m4 m4/libtool.m4
autoreconf --force --install -v
CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing -fstack-protector" \
  ./configure --prefix=/usr --mandir=%{_mandir} --libdir=%{_libdir} --disable-static
make %{?_smp_mflags}

%install
mkdir -p $RPM_BUILD_ROOT/{%{_mandir}/{man1,man3},usr/{bin,lib,include}}
make install DESTDIR=$RPM_BUILD_ROOT
for f in `find $RPM_BUILD_ROOT/%{_mandir} -type f -print ` ; do
  if [ `wc -l <$f` -eq 1 ] && grep -q "^\.so " $f ; then
    linkto=`sed -e "s|^\.so ||" $f`
    [ -f "`dirname $f`/$linkto" ] && ln -sf "$linkto" $f
  fi
done
cp %{S:2} .
rm -rf $RPM_BUILD_ROOT/usr/share/doc/tiff*
rm -f $RPM_BUILD_ROOT/%{_libdir}/*.la
find html -name "Makefile*" | xargs rm

%post -n libtiff3 -p /sbin/ldconfig

%postun -n libtiff3 -p /sbin/ldconfig

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
/usr/bin/*
%doc html
%doc README COPYRIGHT VERSION ChangeLog TODO RELEASE-DATE
%doc %{_mandir}/man1/*

%files -n libtiff3
%defattr(-,root,root)
%doc README COPYRIGHT README.SUSE
%{_libdir}/*.so.*

%files -n libtiff-devel
%defattr(-,root,root)
/usr/include/*
%{_libdir}/*.so
%doc %{_mandir}/man3/*

%changelog
* Wed Jun 20 2012 pgajdos@suse.com
- fixed
  * CVE-2012-2113 [bnc#767852]
  * CVE-2012-2088 [bnc#767854]
* Mon Apr  2 2012 pgajdos@suse.com
- fixed CVE-2012-1173 [bnc#753362]
* Thu Apr 14 2011 pgajdos@suse.cz
- fixed following vulnerabilities:
  * integer overflow CVE-2010-4665 [bnc#687442]
  * buffer overflow CVE-2009-5022 [bnc#687441]
* Thu Mar 31 2011 pgajdos@suse.cz
- fixed regression caused by previous update [bnc#682871]
  * modified CVE-2011-0192.patch
- fixed buffer overflow in thunder decoder [bnc#683337]
  * added CVE-2011-1167.patch
* Thu Mar  3 2011 pgajdos@suse.cz
- fixed buffer overflow [bnc#672510]
  * CVE-2011-0192.patch
* Mon Sep  6 2010 pgajdos@suse.cz
- fixed "Possibly exploitable memory corruption issue in libtiff"
  (see http://bugzilla.maptools.org/show_bug.cgi?id=2228)
  [bnc#624215]
  * scanlinesize.patch
- fixed crash while using libjpeg7 and higher
  * dont-fancy-upsampling.patch
* Mon Jul 12 2010 pgajdos@suse.cz
- updated to 3.9.4: fixes CVE-2010-2065 -- obsoletes
  * integer-overflow.patch
  * NULL-deref.patch
- fixes CVE-2010-2067
* Wed Jun 23 2010 pgajdos@suse.cz
- fixed CVE-2010-2065
  * integer-overflow.patch
  * NULL-deref.patch
-  fixed out of bounds read
  * oob-read.patch
-  fixed CVE-2010-2233
  * getimage-64bit.patch
- [bnc#612879]
* Mon Apr 26 2010 pgajdos@suse.cz
- fixed tiff2pdf output [bnc#599475]
* Fri Mar 26 2010 pgajdos@suse.cz
- fixed typo
* Tue Mar 16 2010 pgajdos@suse.cz
- updated to 3.9.2: fixed many CVE's and obsoletes almost all
  our patches (see ChangeLog for details)
* Tue Dec 15 2009 jengelh@medozas.de
- add baselibs.conf as a source
- enable parallel building
* Thu Aug  6 2009 pgajdos@suse.cz
- fixed integer overflows [bnc#519796]
  * CVE-2009-2347.patch
* Thu Jul  2 2009 nadvornik@suse.cz
- fixed lzw overflow CVE-2009-2285 [bnc#518698]
* Wed Feb  4 2009 nadvornik@suse.cz
- fixed an endless loop on invalid images
  (bnc#444079) CVE-2008-1586
* Tue Jan 13 2009 olh@suse.de
- obsolete old libtiff-64bit on ppc64 (bnc#437293)
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Sun Sep  7 2008 schwab@suse.de
- Fix conflicting options.
* Tue Aug 19 2008 nadvornik@suse.cz
- fixed buffer overflows in LZW code (CVE-2008-2327) [bnc#414946]
* Sun May 18 2008 coolo@suse.de
- fix rename of xxbit packages
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Fri Jul 27 2007 ro@suse.de
- add provides and obsoletes for libtiff to libtiff3 package
* Thu Jul 19 2007 nadvornik@suse.cz
- renamed libtiff to libtiff3
- do not package static libraries
- added zlib-devel to BuildRequires
* Mon Jun 12 2006 nadvornik@suse.cz
- fixed a typo in the previous change [#179051]
* Fri Jun  2 2006 nadvornik@suse.cz
- fixed buffer overflow in tiffsplit (CVE-2006-2656) [#179051]
- fixed buffer overflow in tiff2pdf [#179587]
* Wed Apr 12 2006 nadvornik@suse.cz
- updated to 3.8.2 [#165237]
  * bugfix release
  * fixed several segfaults caused by incorrect tiff data
* Tue Feb  7 2006 nadvornik@suse.cz
- fixed crash on certain tiff images CVE-2006-0405 [#145757]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 nadvornik@suse.cz
- compile with -fstack-protector
* Tue Jan  3 2006 nadvornik@suse.cz
- updated to 3.8.0:
  * Read-only support for custom directories (e.g. EXIF directory)
  * Preliminary support for MS MDI format
* Mon Oct 10 2005 nadvornik@suse.cz
- built with -fno-strict-aliasing
* Fri Jul 15 2005 nadvornik@suse.cz
- updated to 3.7.3
* Tue May 24 2005 nadvornik@suse.cz
- updated to 3.7.2
- fixed 64bit bug in ppm2tiff [#85440]
- fixed buffer overflow in BitsPerSample [#82787]
* Thu Feb 17 2005 nadvornik@suse.cz
- fixed reading of alpha channel
* Sun Jan 16 2005 ro@suse.de
- added c++ to neededforbuild
* Fri Jan  7 2005 nadvornik@suse.cz
- use typedef int int32 on all architectures
* Wed Jan  5 2005 nadvornik@suse.cz
- disabled c++ API as it would add a dependency on c++ libraries
* Mon Jan  3 2005 nadvornik@suse.cz
- updated to 3.7.1: bugfix release
* Wed Dec 15 2004 nadvornik@suse.cz
- added README.SUSE pointing to the documentation [#48601]
- moved man3 to devel subpackage
* Fri Oct 22 2004 nadvornik@suse.cz
- updated to 3.7.0 - security fixes are included in mainstream
* Wed Oct 20 2004 meissner@suse.de
- Initialize ycbcrsubsampling to be not 0 in case
  of bad tiffs to avoid denial of service by divison/0.
* Tue Oct 12 2004 nadvornik@suse.cz
- do not call TIFFTileSize with uninitialized values [#44635]
* Thu Oct  7 2004 pmladek@suse.cz
- fixed much more buffer overflows (the older tiff-alt-bound-CheckMalloc.patch
  is included in the new libtiff-3.6.1-alt-bound.patch now) [#44635]
* Thu Sep 30 2004 nadvornik@suse.cz
- fixed more buffer overflows [#44635]
* Tue Sep 21 2004 nadvornik@suse.cz
- fixed multiple buffer overflows - CAN-2004-0803 [#44635]
- disabled old jpeg support because of security problems [#45116]
* Tue Aug 31 2004 nadvornik@suse.cz
- added LZW support
* Wed Aug 25 2004 kukuk@suse.de
- Create -devel subpackage
- Add libjpeg-devel to neededforbuild
- Avoid /bin/sh in PreRequires
* Fri Jul  2 2004 max@suse.de
- port.h is needed as well.
* Thu May  6 2004 max@suse.de
- Install private headers (tif_dir.h, tiffiop.h).
* Tue Apr 27 2004 nadvornik@suse.cz
- fixed tif_fax3 from cvs [#39515]
* Mon Feb  9 2004 nadvornik@suse.cz
- updated to 3.6.1
- fixed dangerous compiler warnings
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr and %%run_ldconfig
* Tue May 20 2003 ro@suse.de
- remove cvs subdirs
* Sat Jul 27 2002 kukuk@suse.de
- Provide libtiff-devel in libtiff [Bug #17260]
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuild
* Wed Jul  3 2002 nadvornik@suse.cz
- fixed segfault in fax2tiff [bug #16818]
- fixed size of int32 on 64bit architectures
* Tue Jun 25 2002 ro@suse.de
- fixed directory permissions
* Wed Jun 19 2002 nadvornik@suse.cz
- compiled with OJPEG_SUPPORT [bug #16408]
* Thu Apr 18 2002 kukuk@suse.de
- Fix to compile on lib64 architectures
* Wed Feb  6 2002 coolo@suse.de
- use %%_libdir
* Thu Jan 24 2002 okir@suse.de
- Fixed a tempfile race in fax2ps
* Tue Dec 11 2001 nadvornik@suse.cz
- updated to 3.5.7: bugfix release
* Wed May  9 2001 mfabian@suse.de
- bzip2 sources
* Thu Mar 15 2001 schwab@suse.de
- Fix for ia64.
* Fri May 26 2000 bubnikv@suse.cz
- sorted
* Thu May 25 2000 schwab@suse.de
- Fix dso configure check for ia64.
* Thu May 11 2000 nadvornik@suse.cz
- update to 3.5.5
- added BuildRoot
* Tue Jan 25 2000 ro@suse.de
- manpages to /usr/share using macro
* Mon Jan  3 2000 schwab@suse.de
- Update to 3.5.4 (Y2K fix)
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Wed Jan 13 1999 ro@suse.de
- respect systems where libc is libc.so.6.1 (alpha)
* Wed Nov 25 1998 ro@suse.de
- update to 3.4 (final) named 3.4.final for rpm
- moved from /usr/X11R6 to /usr
* Wed Jul 29 1998 werner@suse.de
- Link shared libs explicit with -lc
* Tue May 12 1998 ro@suse.de
- extracted package from libgr / build from own sources
